OiRA

Help

1. It-Tħejjija
2. Involvi
3. L-Identifikazzjoni + Il-Valutazzjoni
4. Il-Pjan ta' Azzjoni
5. Ir-Rapport
6. Stat 0%

# Niżżel u pprintja r-rapport tiegħek

Nirrakkomandaw li dejjem iżżomm verżjoni aġġornata pprintjata tal-valutazzjoni tar-riskji tiegħek (rapport) għad-dispożizzjoni fil-kumpanija tiegħek!

Ir-Rapport

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Il-Pjan ta' Azzjoni

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Ħarsa ġenerali tar-riskji

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Ħarsa ġenerali tal-miżuri.

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More